include "linux-keys-bare"

keycode 100 = AltGr
alt keycode 100 = Compose

altgr keycode  70 = Show_Registers
alt keycode  70 = Scroll_Lock

control altgr keycode  83 = Boot
control altgr keycode 111 = Boot

# Hex keypad keys (for giving a Unicode value in 4 hex digits)
# Follow lt.map and assign Hex_A .. Hex_F to keypad border.
altgr keycode  55 = Hex_C
altgr keycode  69 = Hex_A
altgr keycode  71 = Hex_7
altgr keycode  72 = Hex_8
altgr keycode  73 = Hex_9
altgr keycode  74 = Hex_D
altgr keycode  75 = Hex_4
altgr keycode  76 = Hex_5
altgr keycode  77 = Hex_6
altgr keycode  78 = Hex_E
altgr keycode  79 = Hex_1
altgr keycode  80 = Hex_2
altgr keycode  81 = Hex_3
altgr keycode  82 = Hex_0
altgr keycode  96 = Hex_F
altgr keycode  98 = Hex_B
