# qwertz-layout
keycode  12 = q
keycode  13 = w
keycode  14 = e
keycode  15 = r
keycode  17 = t
keycode  16 = z
keycode  32 = u
keycode  34 = i
keycode  31 = o
keycode  35 = p
#
keycode   0 = a
keycode   1 = s
keycode   2 = d
keycode   3 = f
keycode   5 = g
keycode   4 = h
keycode  38 = j
keycode  40 = k
keycode  37 = l
#
keycode   6 = y
keycode   7 = x
keycode   8 = c
keycode   9 = v
keycode  11 = b
keycode  45 = n
keycode  46 = m
#
