# qwerty-layout
keycode  16 = q
keycode  17 = w
keycode  18 = e
keycode  19 = r
keycode  20 = t
keycode  21 = y
keycode  22 = u
keycode  23 = i
keycode  24 = o
keycode  25 = p
#
keycode  30 = a
keycode  31 = s
keycode  32 = d
keycode  33 = f
keycode  34 = g
keycode  35 = h
keycode  36 = j
keycode  37 = k
keycode  38 = l
#
keycode  44 = z
keycode  45 = x
keycode  46 = c
keycode  47 = v
keycode  48 = b
keycode  49 = n
keycode  50 = m
#
include "compose"
