# Euro and cent
# [Say: "loadkeys euro1" to get Euro and cent with AltGr (right alt)
#  on the positions where many keyboards have 5 and C.
#  To get it displayed, use a latin0 (i.e., latin9) font.]
altgr keycode   6 = currency
altgr keycode  46 = cent
